quantizationtools.QGridContainer
================================

.. abjad-lineage:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer

.. autoclass:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.append
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.children
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.depth
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.depthwise_inventory
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.duration
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.extend
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graph_order
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graphviz_format
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graphviz_graph
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.improper_parentage
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.index
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.insert
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.leaves
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.name
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.nodes
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.parent
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.parentage_ratios
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.pop
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.preprolated_duration
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.pretty_rtm_format
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.prolation
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.prolations
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.proper_parentage
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.remove
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.root
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.rtm_format
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.start_offset
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.stop_offset
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__add__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__call__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__contains__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__copy__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__deepcopy__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__delitem__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__eq__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__getitem__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__getstate__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__iter__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__len__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__ne__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__repr__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__setitem__
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__setstate__

Bases
-----

- :py:class:`rhythmtreetools.RhythmTreeContainer <abjad.tools.rhythmtreetools.RhythmTreeContainer.RhythmTreeContainer.RhythmTreeContainer>`

- :py:class:`rhythmtreetools.RhythmTreeNode <abjad.tools.rhythmtreetools.RhythmTreeNode.RhythmTreeNode.RhythmTreeNode>`

- :py:class:`datastructuretools.TreeContainer <abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer>`

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.children
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.depth
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.duration
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graph_order
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graphviz_graph
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.leaves
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.nodes
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.parent
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.parentage_ratios
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.pretty_rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.prolation
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.prolations
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.root
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.start_offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.stop_offset
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.name
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.preprolated_duration
   :noindex:

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.append
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.extend
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.index
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.insert
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.pop
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.remove
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__add__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__contains__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__copy__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__delitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__getitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__iter__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__len__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__setitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__setstate__
   :noindex:
